@@ -521,17 +521,16 @@ def test_hit_column():
 def test_closed_searcher():
     from whoosh.reading import ReaderClosed
 
-    schema = fields.Schema(key=fields.KEYWORD(stored=True, sortable=True,
-                                              spelling=True))
+    schema = fields.Schema(key=fields.KEYWORD(stored=True, sortable=True))
 
     with TempStorage() as st:
         ix = st.create_index(schema)
         with ix.writer() as w:
-            w.add_document(key=u("alfa"))
-            w.add_document(key=u("bravo"))
-            w.add_document(key=u("charlie"))
-            w.add_document(key=u("delta"))
-            w.add_document(key=u("echo"))
+            w.add_document(key=u"alfa")
+            w.add_document(key=u"bravo")
+            w.add_document(key=u"charlie")
+            w.add_document(key=u"delta")
+            w.add_document(key=u"echo")
 
         s = ix.searcher()
         r = s.search(query.TermRange("key", "b", "d"))
@@ -541,8 +540,6 @@ def test_closed_searcher():
             assert r[0]["key"] == "bravo"
         with pytest.raises(ReaderClosed):
             s.reader().column_reader("key")
-        with pytest.raises(ReaderClosed):
-            s.reader().has_word_graph("key")
         with pytest.raises(ReaderClosed):
             s.suggest("key", "brovo")
 
@@ -552,7 +549,6 @@ def test_closed_searcher():
         assert r[0]["key"] == "bravo"
         c = s.reader().column_reader("key")
         assert c[1] == "bravo"
-        assert s.reader().has_word_graph("key")
         assert s.suggest("key", "brovo") == ["bravo"]
 
 
